==> jc-1.4.0.tar.gz: java/io/ByteArrayInputStream.h <==
// public class java.io.ByteArrayInputStream

// class file dependencies
// @dep_class a68cc27886fd8be3 java_io_ByteArrayInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_InputStream

#include "java/io/InputStream.h"

#ifndef _JC_java_io_ByteArrayInputStream_H_
#define _JC_java_io_ByteArrayInputStream_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_ByteArrayInputStream$sub_refs	_jc_java_io_ByteArrayInputStream$sub_refs;
typedef struct _jc_java_io_ByteArrayInputStream$sub_nonrefs	_jc_java_io_ByteArrayInputStream$sub_nonrefs;
typedef struct _jc_java_io_ByteArrayInputStream$refs	_jc_java_io_ByteArrayInputStream$refs;
typedef struct _jc_java_io_ByteArrayInputStream$nonrefs	_jc_java_io_ByteArrayInputStream$nonrefs;
typedef struct _jc_java_io_ByteArrayInputStream$object	_jc_java_io_ByteArrayInputStream$object;

typedef const struct _jc_java_io_ByteArrayInputStream$vmethods	_jc_java_io_ByteArrayInputStream$vmethods;
typedef const struct _jc_java_io_ByteArrayInputStream$vtable	_jc_java_io_ByteArrayInputStream$vtable;
typedef const struct _jc_java_io_ByteArrayInputStream$vtype	_jc_java_io_ByteArrayInputStream$vtype;

// Constructors
extern void _jc_java_io_ByteArrayInputStream$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *, struct _jc_byte_array *);
extern void _jc_java_io_ByteArrayInputStream$method$_init$4ff4a7925ef7b06c(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *, struct _jc_byte_array *, jint, jint);

// Virtual methods
extern jint _jc_java_io_ByteArrayInputStream$method$available$81975cc608605037(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *);
extern void _jc_java_io_ByteArrayInputStream$method$mark$422af117ab27d9db(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *, jint);
extern jboolean _jc_java_io_ByteArrayInputStream$method$markSupported$66435a81b7b2f2dc(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *);
extern jint _jc_java_io_ByteArrayInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *);
extern jint _jc_java_io_ByteArrayInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_java_io_ByteArrayInputStream$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *);
extern jlong _jc_java_io_ByteArrayInputStream$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *, jlong);

// Virtual method descriptors
extern _jc_method _jc_java_io_ByteArrayInputStream$method_info$available$81975cc608605037;
extern _jc_method _jc_java_io_ByteArrayInputStream$method_info$mark$422af117ab27d9db;
extern _jc_method _jc_java_io_ByteArrayInputStream$method_info$markSupported$66435a81b7b2f2dc;
extern _jc_method _jc_java_io_ByteArrayInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_io_ByteArrayInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_java_io_ByteArrayInputStream$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_java_io_ByteArrayInputStream$method_info$skip$4e431136b5c4614a;

// Virtual methods structure
struct _jc_java_io_ByteArrayInputStream$vmethods {
	jint	(*available$81975cc608605037)(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *);
	void	(*mark$422af117ab27d9db)(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *, jint);
	jboolean	(*markSupported$66435a81b7b2f2dc)(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *);
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *, struct _jc_byte_array *, jint, jint);
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *);
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *, jlong);
};

// Vtable
struct _jc_java_io_ByteArrayInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_ByteArrayInputStream$vmethods	java_io_ByteArrayInputStream;
};

// Vtype
struct _jc_java_io_ByteArrayInputStream$vtype {
	_jc_type			type;
	_jc_java_io_ByteArrayInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_ByteArrayInputStream$sub_refs {
	_jc_byte_array	*buf;
};

// Reference instance fields (object)
struct _jc_java_io_ByteArrayInputStream$refs {
    _jc_java_io_ByteArrayInputStream$sub_refs	java_io_ByteArrayInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_ByteArrayInputStream$sub_nonrefs {
	jint	pos;
	jint	mark;
	jint	count;
};

// Non-reference instance fields (object)
struct _jc_java_io_ByteArrayInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_ByteArrayInputStream$sub_nonrefs	java_io_ByteArrayInputStream;
};

// Object instance structure
struct _jc_java_io_ByteArrayInputStream$object {
	_jc_java_io_ByteArrayInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_ByteArrayInputStream$vtype	*vtype;
	_jc_java_io_ByteArrayInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_ByteArrayInputStream$vtype _jc_java_io_ByteArrayInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_ByteArrayInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_ByteArrayInputStream$class_object;

#endif	/* _JC_java_io_ByteArrayInputStream_H_ */

==> jc-1.4.6.tar.gz: java/io/ByteArrayInputStream.h <==
// public class java.io.ByteArrayInputStream

// class file dependencies
// @dep_class a68cc27886fd8be3 java_io_ByteArrayInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_InputStream

#include "java/io/InputStream.h"

#ifndef _JC_java_io_ByteArrayInputStream_H_
#define _JC_java_io_ByteArrayInputStream_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_ByteArrayInputStream$sub_refs	_jc_java_io_ByteArrayInputStream$sub_refs;
typedef struct _jc_java_io_ByteArrayInputStream$sub_nonrefs	_jc_java_io_ByteArrayInputStream$sub_nonrefs;
typedef struct _jc_java_io_ByteArrayInputStream$refs	_jc_java_io_ByteArrayInputStream$refs;
typedef struct _jc_java_io_ByteArrayInputStream$nonrefs	_jc_java_io_ByteArrayInputStream$nonrefs;
typedef struct _jc_java_io_ByteArrayInputStream$object	_jc_java_io_ByteArrayInputStream$object;

typedef const struct _jc_java_io_ByteArrayInputStream$vmethods	_jc_java_io_ByteArrayInputStream$vmethods;
typedef const struct _jc_java_io_ByteArrayInputStream$vtable	_jc_java_io_ByteArrayInputStream$vtable;
typedef const struct _jc_java_io_ByteArrayInputStream$vtype	_jc_java_io_ByteArrayInputStream$vtype;

// Constructors
extern void _jc_java_io_ByteArrayInputStream$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_java_io_ByteArrayInputStream$method$_init$4ff4a7925ef7b06c(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_io_ByteArrayInputStream$method$available$81975cc608605037(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_io_ByteArrayInputStream$method$mark$422af117ab27d9db(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_java_io_ByteArrayInputStream$method$markSupported$66435a81b7b2f2dc(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_java_io_ByteArrayInputStream$method$read$1a981297cb524963(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_java_io_ByteArrayInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_io_ByteArrayInputStream$method$reset$229a80b3e8394a0f(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *) _JC_JCNI_ATTR;
extern jlong _jc_java_io_ByteArrayInputStream$method$skip$4e431136b5c4614a(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *, jlong) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_ByteArrayInputStream$method_info$available$81975cc608605037;
extern _jc_method _jc_java_io_ByteArrayInputStream$method_info$mark$422af117ab27d9db;
extern _jc_method _jc_java_io_ByteArrayInputStream$method_info$markSupported$66435a81b7b2f2dc;
extern _jc_method _jc_java_io_ByteArrayInputStream$method_info$read$1a981297cb524963;
extern _jc_method _jc_java_io_ByteArrayInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_java_io_ByteArrayInputStream$method_info$reset$229a80b3e8394a0f;
extern _jc_method _jc_java_io_ByteArrayInputStream$method_info$skip$4e431136b5c4614a;

// Virtual methods structure
struct _jc_java_io_ByteArrayInputStream$vmethods {
	jint	(*available$81975cc608605037)(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *) _JC_JCNI_ATTR;
	void	(*mark$422af117ab27d9db)(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *, jint) _JC_JCNI_ATTR;
	jboolean	(*markSupported$66435a81b7b2f2dc)(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$1a981297cb524963)(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*reset$229a80b3e8394a0f)(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *) _JC_JCNI_ATTR;
	jlong	(*skip$4e431136b5c4614a)(_jc_env *, struct _jc_java_io_ByteArrayInputStream$object *, jlong) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_ByteArrayInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_ByteArrayInputStream$vmethods	java_io_ByteArrayInputStream;
};

// Vtype
struct _jc_java_io_ByteArrayInputStream$vtype {
	_jc_type			type;
	_jc_java_io_ByteArrayInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_ByteArrayInputStream$sub_refs {
	_jc_byte_array	*buf;
};

// Reference instance fields (object)
struct _jc_java_io_ByteArrayInputStream$refs {
    _jc_java_io_ByteArrayInputStream$sub_refs	java_io_ByteArrayInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_ByteArrayInputStream$sub_nonrefs {
	jint	pos;
	jint	mark;
	jint	count;
};

// Non-reference instance fields (object)
struct _jc_java_io_ByteArrayInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_ByteArrayInputStream$sub_nonrefs	java_io_ByteArrayInputStream;
};

// Object instance structure
struct _jc_java_io_ByteArrayInputStream$object {
	_jc_java_io_ByteArrayInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_ByteArrayInputStream$vtype	*vtype;
	_jc_java_io_ByteArrayInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_ByteArrayInputStream$vtype _jc_java_io_ByteArrayInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_ByteArrayInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_ByteArrayInputStream$class_object;

#endif	/* _JC_java_io_ByteArrayInputStream_H_ */
